@@ -394,8 +394,9 @@ def compute_alpha_signal_ls(lo_df=None, core_tokens=['BTC', 'ETH'], extra_tokens
 
 def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_tokens=['AVAX'], moderating_factor = 0.1, frequency='weekly', generate_kpis = True, plot_html=True, stop_loss_quantile = 0.75,take_profit_quantile = 0.75,write_excel_file = True, local_root_directory = None, plot_metrics = True,plot_html_save = True):
     ssjs = core_tokens + extra_tokens
+    universe_literal = '_'.join(ssjs)
     if plot_html:
-        title = 'HedgeFarm Strategy'
+        title = f'HedgeFarm Strategy Universe {universe_literal} moderating factor {moderating_factor}'
         backtest_df = data_df[['COMBO_STRAT']].copy()
         backtest_df.columns = ['strategy']
         fig = realtime_plotting_utility.plot_multiple_time_series(
@@ -664,10 +665,10 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
         freq_aggregated_df = freq_aggregated_df.set_index(['year', 'month'])
         freq_aggregated_df = freq_aggregated_df.drop(columns=['date', 'epoch'])
 
-        universe_literal = '_'.join(ssjs)
+
 
         if write_excel_file:
-            writer = pd.ExcelWriter(local_root_directory + 'weekly_ls_epochs_details_ls.xlsx',
+            writer = pd.ExcelWriter(local_root_directory + f'{moderating_factor}_{universe_literal}_weekly_ls_epochs_details_ls.xlsx',
                                     engine='xlsxwriter')
             freq_aggregated_df.to_excel(writer, sheet_name='epoch')
             writer.save()
@@ -686,7 +687,6 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
             past_returns.to_excel(writer, sheet_name='common')
             writer.save()
 
-    btd_kpis, ytd_kpis, past_returns = riskmetrics.compute_extensive_kpis(data_df=data_df.copy(),strat='COMBO_STRAT')
     return payload_message
 
 
