@@ -717,7 +717,8 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
                 fig.show()
 
             if write_file:
-                writer = pd.ExcelWriter(local_root_directory + f'advance_kpis_details_{title}.xlsx',
+                clean_title = title.replace(' ','_')
+                writer = pd.ExcelWriter(local_root_directory + f'advance_kpis_details_{clean_title}.xlsx',
                                         engine='xlsxwriter')
 
             btd_kpis, ytd_kpis, past_returns = compute_extensive_kpis(data_df=daily_df.copy(),
@@ -736,7 +737,8 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
 
                 writer.save()
             if write_file:
-                writer = pd.ExcelWriter(local_root_directory + f'perf_dd_{me_strat_name}_{title}.xlsx',
+                clean_title = title.replace(' ', '_')
+                writer = pd.ExcelWriter(local_root_directory + f'perf_dd_{me_strat_name}_{clean_title}.xlsx',
                                         engine='xlsxwriter')
                 data.to_excel(writer, sheet_name='kpi')
                 writer.save()
@@ -808,7 +810,8 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
                 'epoch realized max drawdown'].round(decimals=2)
 
             if write_file:
-                writer = pd.ExcelWriter(local_root_directory + f'epoch_{me_strat_name}_{title}.xlsx',
+                clean_title = title.replace(' ','_')
+                writer = pd.ExcelWriter(local_root_directory + f'epoch_{me_strat_name}_{clean_title}.xlsx',
                                         engine='xlsxwriter')
                 epochkpis_df.to_excel(writer, sheet_name='kpis per epoch')
                 writer.save()
